@@ -1,3 +1,6 @@
+from django.utils.translation import gettext_lazy as _
+
+from drf_spectacular.utils import extend_schema, extend_schema_view
 from rest_framework import viewsets
 
 from vng_api_common.caching import conditional_retrieve
@@ -6,21 +9,12 @@ from .models import Group, Hobby, Person
 from .serializers import GroupSerializer, HobbySerializer, PersonSerializer
 
 
+@extend_schema_view(retrieve=extend_schema(description="Some description"))
 @conditional_retrieve(extra_depends_on={"group"})
 class PersonViewSet(viewsets.ReadOnlyModelViewSet):
-    """
-    Title
-
-    Summary
-
-    More summary
-
-    retrieve:
-    Some description
-    """
-
     queryset = Person.objects.all()
     serializer_class = PersonSerializer
+    global_description = _("This is the global resource description")
 
 
 @conditional_retrieve()
