@@ -1,15 +1,14 @@
 import logging
 import re
 import uuid
-from typing import Optional, Union
+from typing import TYPE_CHECKING, List, Optional, Union
 
 from django.apps import apps
 from django.conf import settings
 from django.db import models
 from django.http import HttpRequest
-from django.urls import Resolver404, get_resolver, get_script_prefix
-from django.utils.encoding import smart_text
-from django.utils.module_loading import import_string
+from django.urls import Resolver404, ResolverMatch, get_resolver, get_script_prefix
+from django.utils.encoding import smart_str
 
 from rest_framework.utils import formatting
 from zds_client.client import ClientError
@@ -25,6 +24,8 @@ except ImportError:
         underscoreToCamel as _underscore_to_camel,
     )
 
+if TYPE_CHECKING:
+    from rest_framework.viewsets import ViewSet
 
 logger = logging.getLogger(__name__)
 
@@ -54,20 +55,22 @@ class NotAViewSet(Exception):
     pass
 
 
-def get_viewset_for_path(path: str, method="GET") -> "rest_framework.viewsets.ViewSet":
+def resolve_path(path: str, resolver=None, script_prefix=None) -> ResolverMatch:
+    resolver = resolver or get_resolver()
+    prefix = script_prefix or get_script_prefix()
+    path = path.replace(prefix, "/", 1)
+    try:
+        return resolver.resolve(path)
+    except Resolver404 as exc:
+        raise models.ObjectDoesNotExist("URL did not resolve") from exc
+
+
+def get_viewset_for_path(path: str, method="GET") -> "ViewSet":
     """
     Look up which viewset matches a path.
     """
     # NOTE: this doesn't support setting a different urlconf on the request
-    resolver = get_resolver()
-    prefix = get_script_prefix()
-    path = path.replace(prefix, "/", 1)
-
-    try:
-        resolver_match = resolver.resolve(path)
-    except Resolver404 as exc:
-        raise models.ObjectDoesNotExist("URL did not resolve") from exc
-    callback, callback_args, callback_kwargs = resolver_match
+    callback, callback_args, callback_kwargs = resolve_path(path)
 
     if not hasattr(callback, "cls"):
         raise NotAViewSet(f"Callback for {path} does not look like a viewset")
@@ -100,6 +103,61 @@ def get_resource_for_path(path: str) -> models.Model:
     return viewset.get_queryset().get(**filter_kwargs)
 
 
+def get_resources_for_paths(paths: List[str]) -> Optional[models.QuerySet]:
+    """
+    Retrieve API instances belonging to a list of (detail) paths.
+
+    This is the bulk version of :func:`vng_api_common.utils.get_resource_for_path`,
+    which doesn't scale well when a lot of paths are involved. This replaces many
+    queries with a single bulk query.
+
+    .. warning::
+
+        This means that all the resource paths must point to the same resource, as the
+        viewset will only be fetched once from the first item and used to retrieve
+        all the resources.
+
+        This function compares the number of resolved instances vs the number of input
+        paths, and if that is not equal, there's something off and a :class:`RuntimeError`
+        is raised.
+    """
+    if not paths:
+        return None
+
+    # NOTE: this doesn't support setting a different urlconf on the request
+    resolver = get_resolver()
+    prefix = get_script_prefix()
+    lookup_kwarg_values = []
+
+    for path in paths:
+        callback, callback_args, callback_kwargs = resolve_path(
+            path,
+            resolver=resolver,
+            script_prefix=prefix,
+        )
+
+        if not hasattr(callback, "cls"):
+            raise NotAViewSet(f"Callback for {path} does not look like a viewset")
+
+        viewset_cls = callback.cls
+        lookup_url_kwarg = viewset_cls.lookup_url_kwarg or viewset_cls.lookup_field
+        lookup_kwarg_values.append(callback_kwargs[lookup_url_kwarg])
+
+    queryset = viewset_cls().get_queryset()
+    # drop any joins or prefetch_related to speed things up even more
+    queryset = queryset.select_related(None).prefetch_related(None)
+
+    filtered_queryset = queryset.filter(
+        **{f"{viewset_cls.lookup_field}__in": lookup_kwarg_values}
+    )
+    if not len(filtered_queryset) == len(paths):
+        raise RuntimeError(
+            f"Some paths could not be resolved with viewset {viewset_cls} - are you sure "
+            "that all paths point to the same resource?"
+        )
+    return filtered_queryset
+
+
 def underscore_to_camel(input_: Union[str, int]) -> str:
     """
     Convert a string from under_score to camelCase.
@@ -197,7 +255,7 @@ def get_view_summary(view_cls):
         summary = view_cls.__doc__.split("\n\n", 1)[1].split(":", 1)[0]
         if "\n\n" in summary:
             summary = summary.rsplit("\n\n", 1)[0].strip().replace("\r", "")
-            return formatting.dedent(smart_text(summary))
+            return formatting.dedent(smart_str(summary))
     except (AttributeError, IndexError):
         pass
 
@@ -210,3 +268,20 @@ def get_field_attribute(
     ModelClass = apps.get_model(model_string, require_ready=False)
     field = ModelClass._meta.get_field(field_name)
     return getattr(field, attr_name, None)
+
+
+def get_schema_endpoints(endpoints):
+    filtered_endpoints = []
+
+    for path, path_regex, method, callback in endpoints:
+        is_excluded = any(
+            (
+                path.endswith(excluded_path)
+                for excluded_path in settings.DRF_EXCLUDED_ENDPOINTS
+            )
+        )
+
+        if not is_excluded:
+            filtered_endpoints.append((path, path_regex, method, callback))
+
+    return filtered_endpoints
